@@ -175,6 +175,10 @@ public:
                 }
                 int socket_fd = prepareASyncSocketGetSocketFd(addrinfo, timeout);
                 freeInternalAddrinfo();
+                if (socket_fd < 0)
+                {
+                        return -1;
+                }
                 ssl_ = SSL_new(ssl_ctx_);
                 if (ssl_ == 0)
                 {
@@ -242,6 +246,51 @@ private:
                 siglongjmp(jump_buffer_, -1);
         }
 
+#ifdef YASKKSERV_CONFIG_MACRO_HAVE_SYMBOL_RESOLV_RETRANS_RETRY
+        struct addrinfo *prepareASyncSocketGetAddrinfo(const char *server, const char *service, float timeout, bool is_ipv6)
+        {
+                DEBUG_ASSERT_POINTER(server);
+                DEBUG_PRINTF("    try getaddrinfo\n");
+                res_state res = &_res;
+                int int_timeout = static_cast<int>(timeout);
+                if (int_timeout < 1)
+                {
+                        int_timeout = 1;
+                }
+                res->retrans = int_timeout;
+                res->retry = 1;
+                DEBUG_PRINTF("  res->retrans=%d  res->retry=%d\n", res->retrans, res->retry);
+                struct addrinfo hints;
+                memset(&hints, 0, sizeof(hints));
+                hints.ai_flags = 0;
+                if (is_ipv6)
+                {
+                        hints.ai_family = AF_UNSPEC; // IPv4 or IPv6
+                }
+                else
+                {
+                        hints.ai_family = AF_INET;
+                }
+                hints.ai_socktype = SOCK_STREAM;
+                hints.ai_protocol = 0;
+                hints.ai_addr = 0;
+                hints.ai_canonname = 0;
+                hints.ai_next = 0;
+                getaddrinfo_result_ = EAI_SYSTEM;
+                internal_addrinfo_ = 0;
+                getaddrinfo_result_ = getaddrinfo(server, service, &hints, &internal_addrinfo_);
+                DEBUG_PRINTF("    done getaddrinfo getaddrinfo_result_=%d internal_addrinfo_=%p\n", getaddrinfo_result_, internal_addrinfo_);
+                if (getaddrinfo_result_ == 0)
+                {
+                        DEBUG_PRINTF("    getaddrinfo() success internal_addrinfo_=%p\n", internal_addrinfo_);
+                }
+                else
+                {
+                        internal_addrinfo_ = 0;
+                }
+                return internal_addrinfo_;
+        }
+#else  // YASKKSERV_CONFIG_MACRO_HAVE_SYMBOL_RESOLV_RETRANS_RETRY
         // ॢդ addrinfo ֤ޤ addrinfo  0 ʳξɬ freeaddrinfo() ǲɬפ뤳ȤդɬפǤԤʤ 0 ֤ޤ
 #ifdef YASKKSERV_CONFIG_FUNCTION_HAVE_TIMER_CREATE
         struct addrinfo *prepareASyncSocketGetAddrinfo(const char *server, const char *service, float timeout, bool is_ipv6)
@@ -410,6 +459,7 @@ private:
                 return internal_addrinfo_;
         }
 #endif // YASKKSERV_CONFIG_FUNCTION_HAVE_TIMER_CREATE
+#endif // YASKKSERV_CONFIG_MACRO_HAVE_SYMBOL_RESOLV_RETRANS_RETRY
 
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wold-style-cast"
